@@ -74,7 +74,7 @@ class AttrDict(OrderedDict):
 
 	@classmethod
 	def from_yaml(cls, path_or_file, if_exists=False):
-		if instance(path_or_file, str_types):
+		if isinstance(path_or_file, str_types):
 			if if_exists and not os.path.exists(path_or_file): return cls()
 			with open(path_or_file) as src:
 				return cls(yaml.load(src, OrderedDictYAMLLoader))
